@@ -6,15 +6,17 @@ pub struct MemberInfo {
     pub access: String,
     pub data_type: String,
     pub pure_data_type: String,
+    pub line_no: i32
 }
 
 impl MemberInfo {
-    pub fn new(name: &str, access: &str, data_type: String) -> Self {
+    pub fn new(name: &str, access: String, data_type: String) -> Self {
         MemberInfo {
             name: name.to_string(),
-            access: access.to_string(),
+            access,
             data_type,
             pure_data_type: "".to_string(),
+            line_no: 0
         }
     }
 }
@@ -26,22 +28,20 @@ pub struct MethodInfo {
     pub parameters: Vec<String>,
     pub return_type: String,
     pub pure_return_type: String,
+    pub line_no: i32,
 }
 
 impl MethodInfo {
-    pub fn new(name: &str, access: &str, parameters: Vec<String>, return_type: String) -> Self {
+    pub fn new(name: &str, access: String, parameters: Vec<String>, return_type: String) -> Self {
         MethodInfo {
             name: name.to_string(),
-            access: access.to_string(),
+            access,
             parameters,
             return_type,
             pure_return_type: "".to_string(),
+            line_no: 0
         }
     }
-
-    pub fn parameter_too_long(&self) -> bool {
-        self.parameters.len() > 5
-    }
 }
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
