@@ -49,7 +49,8 @@ lazy_static! {
 ^(?P<name>[A-Za-z0-9_]+)
 \t(?P<data_type>[^\t]+)
 \t([^\t]+.*?")
-\t(?P<tag_type>[A-Za-z]+)"#
+\t(?P<tag_type>[A-Za-z]+)
+\tline:(?P<line_no>[0-9]+)"#
     )
     .unwrap();
     static ref RE_CLASS: Regex = Regex::new(
@@ -63,11 +64,12 @@ lazy_static! {
     static ref RE_TYPE: Regex =
         Regex::new(r"/\^([ ]*)(?P<datatype>[A-Za-z0-9_.]+)([^A-Za-z0-9_]+)(.*)\$/").unwrap();
     static ref RUST_TYPE: Regex = Regex::new(
-        r"/\^([ ]*)([A-Za-z0-9_.]+)(\t|\s)([A-Za-z0-9_.]+)\s*:(\t|\s)*(?P<datatype>[A-Za-z0-9_.<>]+)"
+        r"/\^([ ]*)(?P<field>[A-Za-z0-9_.\s]+)\s*:(\t|\s)*(?P<datatype>[A-Za-z0-9_.<>]+)"
     ).unwrap();
     static ref PURE_RUST_TYPE: Regex = Regex::new(
         r"((Vec|Option|<)*)(?P<datatype>[A-Za-z0-9_]+)>*"
     ).unwrap();
+
     static ref GO_TYPE: Regex =
         Regex::new(r"(?x)/\^([\s]*)
 ([A-Za-z0-9_.]+)
@@ -78,6 +80,7 @@ lazy_static! {
     ).unwrap();
 
     static ref PARAMETER: Regex = Regex::new(r"/.*\((?P<parameters>(.*?))\).*/").unwrap();
+    static ref RUST_RETURN_TYPE: Regex = Regex::new(r"\s->\s(?P<datatype>[A-Za-z0-9_.]+)\s").unwrap();
 
     static ref TYPE_KEYWORDS: [&'static str; 18] = [
         "private",
@@ -177,14 +180,15 @@ impl CtagsParser {
 
         let name = &captures["name"];
         let tag_type = &captures["tag_type"];
+        let line_no: i32 = (&captures["line_no"]).parse().unwrap_or(0);
 
-        let mut access = "";
+        let mut access = "".to_string();
         if let Some(capts) = RE_ACCESS.captures(line) {
             let match_access = &capts["access"];
             match match_access {
-                "public" => access = "+",
-                "private" => access = "-",
-                "protected" => access = "#",
+                "public" => access = "+".to_string(),
+                "private" => access = "-".to_string(),
+                "protected" => access = "#".to_string(),
                 &_ => {}
             }
         }
@@ -206,9 +210,17 @@ impl CtagsParser {
                 if let Some(capts) = RUST_TYPE.captures(line) {
                     data_type = (&capts["datatype"]).to_string();
 
+                    let field_with_access = (&capts["field"]).to_string();
+                    access = Self::parse_rust_access(field_with_access);
+
                     if let Some(ty) = PURE_RUST_TYPE.captures(data_type.as_str()) {
                         pure_data_type = (&ty["datatype"]).to_string();
                     }
+                } else if let Some(capts) = RUST_RETURN_TYPE.captures(line) {
+                    data_type = (&capts["datatype"]).to_string();
+                    if data_type == "Self" {
+                        data_type = clazz.name.to_string()
+                    }
                 }
             }
             "Go" => {
@@ -226,6 +238,7 @@ impl CtagsParser {
 
         if tag_type.eq("member") || tag_type.eq("field") || tag_type.eq("property") {
             let mut member = MemberInfo::new(name, access, data_type);
+            member.line_no = line_no;
             if !pure_data_type.is_empty() {
                 member.pure_data_type = pure_data_type;
             }
@@ -233,6 +246,7 @@ impl CtagsParser {
         } else if tag_type.eq("method") || tag_type.eq("function") {
             let parameters = Self::pick_parameter_list(&captures[3]);
             let mut method = MethodInfo::new(name, access, parameters, data_type);
+            method.line_no = line_no;
             if !pure_data_type.is_empty() {
                 method.pure_return_type = pure_data_type;
             }
@@ -240,8 +254,20 @@ impl CtagsParser {
         }
     }
 
-    pub fn datatype_supported(lang: &str) -> bool {
-        return lang == "C++" || lang == "C#" || lang == "Java";
+    fn parse_rust_access(field_with_access: String) -> String {
+        let split = field_with_access.split(" ")
+            .map(|s| s.to_string())
+            .collect::<Vec<String>>();
+
+        if split.len() > 1 {
+            return if split[0] == "pub" {
+                "+".to_string()
+            } else {
+                "#".to_string()
+            }
+        }
+
+        "-".to_string()
     }
 
     pub fn remove_keywords(mut line: String) -> String {
@@ -255,13 +281,11 @@ impl CtagsParser {
     fn lookup_class_from_map(&mut self, line: &str) -> Option<&mut ClassInfo> {
         let mut class_name = "".to_string();
 
-        #[allow(unused_assignments)]
-        let mut package = "".to_string();
-        if let Some(capts) = RE_CLASS.captures(line) {
-            class_name = capts["class_name"].to_string();
+        if let Some(captures) = RE_CLASS.captures(line) {
+            class_name = captures["class_name"].to_string();
         }
 
-        package = class_name.clone();
+        let package = class_name.clone();
         let split = class_name.split(".");
         if let Some(last) = split.last() {
             class_name = last.to_string();
@@ -322,7 +346,6 @@ impl CtagsParser {
                     }
                 })
         ).unwrap_or(vec![])
-
     }
 }
 
@@ -380,6 +403,23 @@ name	src/coco_struct.rs	/^    pub name: String,$/;\"	field	line:22	language:Rust
 
         assert_eq!(1, classes.len());
         assert_eq!("String", classes[0].members[0].data_type);
+        assert_eq!("+", classes[0].members[0].access);
+    }
+
+    #[test]
+    pub fn should_build_rust_method_datatype() {
+        let str =
+            r#"GraphvizRender	graphviz_render.rs	/^pub struct GraphvizRender;$/;"	struct	line:11	language:Rust
+render	graphviz_render.rs	/^    pub fn render(classes: &Vec<ClassInfo>, parse_option: &ParseOption) -> String {$/;"	method	line:35	language:Rust	implementation:GraphvizRender"#;
+
+        let mut lines = vec![];
+        lines.push(str.lines());
+        let parser = CtagsParser::parse_str(lines);
+        let classes = parser.classes();
+
+        assert_eq!(1, classes.len());
+        assert_eq!("render", classes[0].methods[0].name);
+        // assert_eq!("+", classes[0].methods[0].access);
     }
 
     #[test]
@@ -423,8 +463,11 @@ name	src/coco_struct.rs	/^    pub name: String,$/;\"	field	line:22	language:Rust
         assert_eq!("ClassInfo", classes[0].name);
         assert_eq!(7, classes[0].members.len());
         assert_eq!("file", classes[0].members[0].name);
-        assert_eq!("parents", classes[0].members[6].name);
-        assert_eq!("String", classes[0].members[6].pure_data_type);
+
+        let six_member = &classes[0].members[6];
+        assert_eq!("parents", six_member.name);
+        assert_eq!("String", six_member.pure_data_type);
+        assert_eq!(43, six_member.line_no)
     }
 
     #[test]
