@@ -77,11 +77,6 @@ pub fn grep_by_text(matcher: &RegexMatcher, text: &str) -> bool {
     has_match
 }
 
-
-pub fn no_filter(_path: PathBuf, _packages: Vec<String>) -> bool {
-    return true;
-}
-
 pub fn filter_by_packages(path: PathBuf, packages: &Vec<String>) -> bool {
     if packages.len() == 0 {
         return true;
