@@ -20,19 +20,19 @@ impl MermaidRender {
         for clazz in classes {
             let mut dep_map: HashMap<String, String> = HashMap::default();
 
-            let members = render_member(&clazz, &mut dep_map, space, parse_option);
+            let members = render_member(&clazz, &mut dep_map, space, parse_option, &mut class_map);
             let mut methods = vec![];
             if !parse_option.field_only {
                 methods = render_method(&clazz, &mut dep_map, space);
             }
 
             let content = format!("{}{}", members.join(""), methods.join(""));
-            let class_field = clazz.name.clone();
+            let class_name = &clazz.name;
             if clazz.parents.len() > 0 && !parse_option.without_parent {
-                rendered.push(format!("{}{} <|-- {}", space, clazz.parents.join(","), clazz.name));
+                rendered.push(format!("{}{} <|-- {}", space, clazz.parents.join(","), class_name));
             }
 
-            rendered.push(format!("{}class {} {{\n{}{}}}", space, class_field, content, space));
+            rendered.push(format!("{}class {} {{\n{}{}}}", space, class_name, content, space));
 
             for (callee, current_clz) in dep_map {
                 if callee == current_clz {
